<?php
namespace Services;

use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class ApprovalWorkflowService
{
    protected $connection;
    protected $newCode;
    
    public function __construct($entityManager, $newCode, $environment)
    {
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
        $this->newCode       = $newCode;
        $this->environment   = $environment;
    }
    
    /*************
     * Utilities *
     *************/
     
    public function generateCode($newCode)
    {
        $code = $this->environment->getNrOrg();
        $codeAprovacao = $this->newCode->getCodeByTableName($newCode, $code);
        
        return $codeAprovacao;
    }
    
    /**************
     * Procedures *
     **************/
     
    public function executeConsisteOrcamentoGOP($params)
    {
        try{
            $connection = $this->entityManager->getConnection();
            
            $procedure  = new StoredProcedure($connection, 'CONSISTE_ORCAMENTO_GOP');
            $procedure->addParam(new Param('P_CDFILDEST',  Param::PARAM_INPUT,  $params['CDFILDEST'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC',  Param::PARAM_INPUT,  $params['CDFILLANC'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT,  $params['NRDEMANDA'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CONSISTE',   Param::PARAM_OUTPUT, NULL, Param::PARAM_TYPE_STR));
            
            return $procedure->execute();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    /***********
     * Inserts *
     ***********/
    
    public function inserirRegistroAprov($params)
    {
        try {
            $sql = "INSERT INTO APROVALCADA ( NRAPROVALCADA, NRCONFIGALCADA, CDFILDEST, CDFILLANC, NRDEMANDA, CDOPERADOR, IDTPDEMANDA, IDCLASSIFIC, IDOPERACAOALC, IDAPROVADO, DTINCLUSAO ) VALUES ( :P_NEWNRAPROVALCADA, :P_NRCONFIGALCADA, :P_CDFILDEST, :P_CDFILLANC, :P_NRDEMANDA, :P_CDOPERADOR, :P_IDTPDEMANDA, :P_IDCLASSIFIC, :P_IDOPERACAOALC, :P_SITUACAO, SYSDATE )";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_NEWNRAPROVALCADA" => (float) $this->generateCode('APROVALCADA'),
                    "P_NRCONFIGALCADA"   => $params['NRCONFIGALCADA'],
                    "P_CDFILDEST"        => $params['CDFILDEST'],
                    "P_CDFILLANC"        => $params['CDFILLANC'],
                    "P_NRDEMANDA"        => $params['NRDEMANDA'],
                    "P_CDOPERADOR"       => $params['CDOPERADOR'],
                    "P_IDTPDEMANDA"      => $params['IDTPDEMANDA'],
                    "P_IDCLASSIFIC"      => $params['IDCLASSIFIC'],
                    "P_IDOPERACAOALC"    => $params['IDOPERACAOALC'],
                    "P_SITUACAO"         => $params['SITUACAO'],
                )
            );
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /***********
     * Updates *
     ***********/
    
    public function updateDemandaAF($params)
    {
        try {
            $sql = "UPDATE AUTOFORNE SET IDSITAFALCADA = :P_SITUACAO, NRCONFIGALCADA = :P_NRCONFIGALCADA, IDBAIXAAF = DECODE(:P_SITUACAO, 'APROVADA', NULL, 6) WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILDEST"      => $params['CDFILDEST'],
                    "P_CDFILLANC"      => $params['CDFILLANC'],
                    "P_NRCONFIGALCADA" => $params['NRCONFIGALCADA'],
                    "P_SITUACAO"       => $params['SITUACAO'],
                    "P_NRAUTOFORN"     => $params['NRDEMANDA'],
                )
            );
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    /*********
     * Finds *
     *********/
    
    public function verificaAlcada($cdFilialDestino)
    {
        try {
            $sql = "SELECT COUNT(*) FILALCADAS FROM FILIALCADA WHERE CDFILIAL = :P_CDFILDEST";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILDEST" => $cdFilialDestino,
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findDemandaAF($params)
    {
        try {
            $sql = "SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDFORNECED, DTAUTOFORN, VRTOTALAF, IDAUTOFORNEX, IDTIPOLANCAF, IDBAIXAAF, DECODE(CDFILDEST, CDFILLANC, 'UNIDADE', 'MATRIZ') AS LANCAMENTO, CDOPERLANCAF, CDOPERADOR AS COMPRADOR, IDSITAFALCADA , NRCONFIGALCADA FROM AUTOFORNE WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILDEST"      => $params['CDFILDEST'],
                    "P_CDFILLANC"      => $params['CDFILLANC'],
                    "P_NRAUTOFORN"     => $params['NRDEMANDA'],
                )
            );
                
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findAlcadaLancamento($params)
    {
        try {
            $select = "SELECT C.NRCONFIGALCADA AS NRCONFIGALCADA FROM AUTOFORNE A, CONFIGALCADA C, FILIALCADA F WHERE A.CDFILDEST = :P_CDFILDEST AND A.CDFILLANC = :P_CDFILLANC AND A.NRAUTOFORN = :P_NRAUTOFORN AND C.NRCONFIGALCADA = F.NRCONFIGALCADA AND F.CDFILIAL = A.CDFILDEST AND ((C.IDLANCAFEXTRA = A.IDAUTOFORNEX) OR (C.IDLANCAFEXTRA = 'AMBOS')) AND ((C.IDTIPOAF = A.IDTIPOLANCAF) OR (C.IDTIPOAF = 'AMBOS')) AND ((C.IDTPLANC = :P_LANCAMENTO) OR (C.IDTPLANC = 'AMBOS')) AND ((C.IDFORAORC = :P_FORAORCAMENTO) OR (:P_FORAORCAMENTO = 'N')) AND ((IDTIPORCAOP = :P_IDTIPORCAOP AND :P_CDDESPPREV = 'T') OR (IDTIPORCAOP = :P_IDTIPORCAOP AND CDDESPPREV = :P_CDDESPPREV))";
            $std = $this->connection->prepare($select);
            $std->execute(
                array(
                    "P_CDFILDEST"     => $params['CDFILDEST'],
                    "P_CDFILLANC"     => $params['CDFILLANC'],
                    "P_NRAUTOFORN"    => $params['NRDEMANDA'],
                    "P_LANCAMENTO"    => $params['LANCAMENTO'],
                    "P_IDTIPORCAOP"   => $params['IDTIPORCAOP'],
                    "P_CDDESPPREV"    => $params['CDDESPPREV'],
                    "P_FORAORCAMENTO" => $params['FORAORCAMENTO'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findTotalDiaAF($params)
    {
        try {
            $select = "SELECT SUM(VRTOTALAF) AS TOTAL FROM AUTOFORNE A, ITEMAUTF I WHERE A.CDFILDEST = :P_CDFILDEST AND A.NRAUTOFORN <> :P_NRAUTOFORN AND A.CDFILDEST = I.CDFILDEST AND A.NRAUTOFORN = I.NRAUTOFORN AND A.CDFILDEST||A.CDFORNECED||I.CDPRODUTO||I.DTPROGENTAF IN (SELECT ITEMAUTF.CDFILDEST||AUTOFORNE.CDFORNECED||ITEMAUTF.CDPRODUTO||ITEMAUTF.DTPROGENTAF FROM AUTOFORNE, ITEMAUTF WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN)";
            $std = $this->connection->prepare($select);
            $std->execute(
                array(
                    "P_CDFILDEST"     => $params['CDFILDEST'],
                    "P_CDFILLANC"     => $params['CDFILLANC'],
                    "P_NRAUTOFORN"    => $params['NRDEMANDA'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function consisteOrcamento($nrDemanda)
    {
        try {
            $sql = "SELECT * FROM CONSISTORCAMENTO WHERE NRDEMANDA = :P_NRDEMANDA";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_NRDEMANDA" => $nrDemanda,
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function validaOperador($params)
    {
        try {
            $sql = "SELECT CDOPERADOR FROM ALCADAGERFILI WHERE NRCONFIGALCADA = :P_NRCONFIGALCADA AND CDFILIAL = :P_CDFILDEST AND (CDOPERADOR = :P_CDOPERLANC) UNION ALL SELECT CDOPERADOR FROM ALCADAGEROPER WHERE NRCONFIGALCADA = :P_NRCONFIGALCADA AND CDFILIAL = :P_CDFILDEST AND (CDOPERRELACAP = :P_CDOPERLANC)";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILDEST"      => $params['CDFILDEST'],
                    "P_NRCONFIGALCADA" => $params['NRCONFIGALCADA'],
                    "P_CDOPERLANC"     => $params['CDOPERLANC'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    
    }
    
    public function findPrimeiroAprovador($params)
    {
        try {
            $sql = "SELECT NRALCADAGERFILI, CDOPERADOR, VRAPROVCMP, (SELECT MIN(B.VRAPROVCMP) FROM ALCADAGERFILI B WHERE B.CDFILIAL = ALCADAGERFILI.CDFILIAL AND B.NRCONFIGALCADA = ALCADAGERFILI.NRCONFIGALCADA AND B.VRAPROVCMP > ALCADAGERFILI.VRAPROVCMP) VRAPROVCMPMAX FROM ALCADAGERFILI WHERE CDFILIAL = :P_CDFILIAL AND NRCONFIGALCADA = :P_NRCONFIGALCADA AND VRAPROVCMP = (SELECT MIN(C.VRAPROVCMP) FROM ALCADAGERFILI C WHERE C.CDFILIAL = ALCADAGERFILI.CDFILIAL AND C.NRCONFIGALCADA = ALCADAGERFILI.NRCONFIGALCADA AND ((C.VRAPROVCMP > :P_VRAPROVCMP) OR NVL(:P_VRAPROVCMP, 'T') = 'T')) ORDER BY VRAPROVCMP";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILIAL"       => $params['CDFILIAL'],
                    "P_NRCONFIGALCADA" => $params['NRCONFIGALCADA'],
                    "P_VRAPROVCMP"     => $params['VRAPROVCMP'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function verificaRegistroAprov($params)
    {
        try {
            $sql = "SELECT * FROM APROVALCADA WHERE NRCONFIGALCADA = :NRCONFIGALCADA AND CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRDEMANDA = :NRDEMANDA AND CDOPERADOR = :CDOPERADOR";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "NRCONFIGALCADA" => $params['NRCONFIGALCADA'],
                    "CDFILDEST"      => $params['CDFILDEST'],
                    "CDFILLANC"      => $params['CDFILLANC'],
                    "NRDEMANDA"      => $params['NRDEMANDA'],
                    "CDOPERADOR"     => $params['CDOPERADOR'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function atualizarRegistroAprov($params)
    {
        try {
            $sql = "UPDATE APROVALCADA SET IDAPROVADO = :IDAPROVADO WHERE NRCONFIGALCADA = :NRCONFIGALCADA AND CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRDEMANDA = :NRDEMANDA AND CDOPERADOR = :CDOPERADOR";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "NRCONFIGALCADA" => $params['NRCONFIGALCADA'],
                    "CDFILDEST"      => $params['CDFILDEST'],
                    "CDFILLANC"      => $params['CDFILLANC'],
                    "NRDEMANDA"      => $params['NRDEMANDA'],
                    "CDOPERADOR"     => $params['CDOPERADOR'],
                    "IDAPROVADO"     => $params['IDAPROVADO'],
                )
            );
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getOperAddress($nrAlcadaGerFili)
    {
        try {
            $sql = "SELECT A.CDOPERADOR, G.NMOPERADOR, G.DSEMAILOPER FROM ALCADAGERFILI A, OPERADOR G WHERE A.NRALCADAGERFILI = :P_NRALCADAGERFILI AND A.CDOPERADOR = G.CDOPERADOR UNION SELECT O.CDOPERRELACAP CDOPERADOR, R.NMOPERADOR, R.DSEMAILOPER FROM ALCADAGERFILI A, ALCADAGEROPER O, OPERADOR R WHERE A.NRALCADAGERFILI = :P_NRALCADAGERFILI AND A.NRCONFIGALCADA = O.NRCONFIGALCADA AND A.CDFILIAL = O.CDFILIAL AND A.CDOPERADOR = O.CDOPERADOR AND O.CDOPERRELACAP = R.CDOPERADOR";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_NRALCADAGERFILI" => $nrAlcadaGerFili,
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getTipoOrcamento($params)
    {
        try {
            $sql = "SELECT DISTINCT IDORIGEMCONS NMITMORCA, NVL(CDDESPPREV, 'T') CDDESPPREV FROM CONSISTORCAMENTO WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRDEMANDA = :P_NRDEMANDA";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    'P_CDFILDEST' => $params['CDFILDEST'],
                    'P_CDFILLANC' => $params['CDFILLANC'],
                    'P_NRDEMANDA' => $params['NRDEMANDA'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDemandaDespesa($params)
    {
        try {
            $sql = "SELECT MAX(CDDESPPREV) CDDESPPREV, 'DESPESA' NMITMORCA FROM PRODDESPPREV, ITEMAUTF WHERE ITEMAUTF.CDPRODUTO LIKE PRODDESPPREV.CDPRODUTO||'%' AND CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRDEMANDA";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    'P_CDFILDEST' => $params['CDFILDEST'],
                    'P_CDFILLANC' => $params['CDFILLANC'],
                    'P_NRDEMANDA' => $params['NRDEMANDA'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDemandaConsumo($params)
    {
        try {
            $sql = "SELECT MAX(PE.NRPERCITEMGOP) NRPERCITEMGOP, 'CONSUMO' NMITMORCA, 'T' CDDESPPREV  FROM PERCITEMDETALGOP PE, ITEMAUTF WHERE PE.NRPERCITEMGOP = '2' AND ITEMAUTF.CDPRODUTO LIKE PE.CDPRODUTO||'%' AND CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRDEMANDA ORDER BY PE.CDPRODUTO ASC";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    'P_CDFILDEST' => $params['CDFILDEST'],
                    'P_CDFILLANC' => $params['CDFILLANC'],
                    'P_NRDEMANDA' => $params['NRDEMANDA'],
                )
            );
                
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findNomeFilial($cdFilialDestino)
    {
        try {
            $sql = "SELECT NMFILIAL FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_CDFILIAL" => $cdFilialDestino,
                )
            );
                
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findNomeAlcada($nrConfigAlcada)
    {
        try {
            $sql = "SELECT NMALCADA FROM CONFIGALCADA WHERE NRCONFIGALCADA = :P_NRCONFIGALCADA";
            $std = $this->connection->prepare($sql);
            $std->execute(
                array(
                    "P_NRCONFIGALCADA" => $nrConfigAlcada,
                )
            );
                
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findOperadorLancamento($cdOperadorLancAF)
    {
        try {
            $sql = "SELECT NMOPERADOR, DSEMAILOPER FROM OPERADOR WHERE CDOPERADOR = :P_CDOPERLANC";
            $std = $this->connection->prepare($sql);
            $std->execute (
                array (
                    'P_CDOPERLANC' => $cdOperadorLancAF,
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getIdUtilWorkflow($cdFilial)
    {
        try {
            $query = "SELECT IDUTLWORKFLOW FROM PARASUPRI WHERE CDFILIAL = :P_CDFILIAL";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "P_CDFILIAL" => $cdFilial,
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getOrcamentoAF($params)
    {
        try {
            $query = "SELECT PROD.CDARVPROD, IM.DTORCAMENTO, IM.VRORCAMENTO VRORCACONSDESP, IDP.VRORCAMENTO VRORCAITEM,
                              I.IDTIPOORCAOP, I.CDDESPPREV
                         FROM ORCAMENTOGOP O INNER JOIN ITEMORCAGOP I ON I.NRORCAMENTOGOP = O.NRORCAMENTOGOP
                                                                     AND I.IDTIPOORCAOP IN ('CONSUMO','DESPENTRADA','DESPDIVERSA')
                                                                     AND I.NRORG = O.NRORG
                                             INNER JOIN APROVAORCAGOP A ON A.NRORCAMENTOGOP = O.NRORCAMENTOGOP
                                                                       AND A.NRORG = O.NRORG
                                             INNER JOIN ITORCAMESGOP IM ON IM.NRITEMORCAOP = I.NRITEMORCAOP
                                                                       AND IM.NRORG = I.NRORG
                                             INNER JOIN ITDETALORCAMESGOP IDP ON IDP.NRITORCAMESGOP = IM.NRITORCAMESGOP
                                                                       AND IDP.NRORG = IM.NRORG
                                             INNER JOIN PRODUTO PROD ON PROD.CDPRODUTO = IDP.CDPRODUTO
                                                                    AND PROD.NRORG = IDP.NRORG
                        WHERE O.CDFILIAL = :P_CDFILDEST
                          AND O.IDPERIODOORCA = :V_IDPERIODOORCA
                          AND O.NRPERIODOORCA = :V_NRPERIODOORCAGOP                                        
                          AND O.NRANOORCAGOP = TO_CHAR(TO_DATE(:V_DATAINI),'YYYY')             
                          AND O.NRORG = :P_NRORG
                          AND TO_DATE(:P_DTPROGENTAF) BETWEEN TO_DATE(:V_DATAINI) AND TO_DATE(:V_DATAFIM)
                          AND TO_NUMBER(TO_CHAR(TO_DATE(:V_DATAINI),'MM')) = TO_NUMBER(TO_CHAR(IM.DTORCAMENTO,'MM'))
                          AND IDP.VRORCAMENTO IS NOT NULL
                          AND EXISTS (SELECT 1
                                        FROM ITEMAUTF AF INNER JOIN PRODUTO P ON AF.CDPRODUTO = P.CDPRODUTO
                                       WHERE AF.CDFILDEST  = :P_CDFILDEST
                                         AND AF.CDFILLANC  = :P_CDFILLANC
                                         AND AF.NRAUTOFORN = :P_NRDEMANDA
                                         AND AF.NRORG      = :P_NRORG
                                         AND P.CDARVPROD LIKE PROD.CDARVPROD||'%'
                                       UNION
                                      SELECT 1
                                        FROM ITEMPEDEXOL I INNER JOIN PRODUTO P ON I.CDPRODUTO = P.CDPRODUTO
                                       WHERE I.CDFILDEST = :P_CDFILDEST
                                         AND I.CDFILLANC = :P_CDFILLANC
                                         AND I.NRPEDEXOL = :P_NRDEMANDA
                                         AND I.NRORG     = :P_NRORG
                                         AND P.CDARVPROD LIKE PROD.CDARVPROD||'%'
                                       UNION
                                      SELECT 1
                                        FROM ITEMSOLI I INNER JOIN PRODUTO P ON I.CDPRODUTO = P.CDPRODUTO
                                       WHERE I.CDFILSOLI = :P_CDFILDEST
                                         AND I.CDFILLAN  = :P_CDFILLANC
                                         AND I.NRSOLICMP = :P_NRDEMANDA
                                         AND I.NRORG     = :P_NRORG
                                         AND P.CDARVPROD LIKE PROD.CDARVPROD||'%')";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "P_CDFILDEST"          => $params['CDFILDEST'],
                    "V_IDPERIODOORCA"      => $params['IDPERIODOORCA'],
                    "V_NRPERIODOORCAGOP"   => $params['NRPERIODOORCAGOP'],
                    "V_DATAINI"            => $params['DATAINI'],
                    "V_DATAFIM"            => $params['DATAFIM'],
                    "P_DTPROGENTAF"        => $params['DTPROGENTAF'],
                    "P_CDFILLANC"          => $params['CDFILLANC'],
                    "P_NRDEMANDA"          => $params['NRDEMANDA'],
                    "P_NRORG"              => $this->environment->getNrOrg(),
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findDataOrcamento($params)
    {
        try {
            $query = "SELECT V_DATAINI, ADD_MONTHS(V_DATAINI,1)-1 V_DATAFIM 
                        FROM (
                            SELECT TO_DATE(CASE WHEN TO_NUMBER(:P_DIA) > TO_NUMBER(TO_CHAR(LAST_DAY(:P_DATA),'DD'))
                                         THEN TO_CHAR(LAST_DAY(:P_DATA),'DD')
                                         ELSE LPAD(:P_DIA,2,'0')
                                    END || TO_CHAR(P.DTMES,'MM/YYYY'),'DD/MM/YYYY') V_DATAINI
                               FROM DATA P
                              WHERE :P_DATA BETWEEN TO_DATE(CASE WHEN TO_NUMBER(:P_DIA) > TO_NUMBER(TO_CHAR(LAST_DAY(:P_DATA),'DD'))
                                                                THEN TO_CHAR(LAST_DAY(:P_DATA),'DD')
                                                                ELSE LPAD(:P_DIA,2,'0')
                                                           END || TO_CHAR(P.DTMES,'MM/YYYY'),'DD/MM/YYYY')
                                               AND ADD_MONTHS(TO_DATE(CASE WHEN TO_NUMBER(:P_DIA) > TO_NUMBER(TO_CHAR(LAST_DAY(:P_DATA),'DD'))
                                                                           THEN TO_CHAR(LAST_DAY(:P_DATA),'DD')
                                                                           ELSE LPAD(:P_DIA,2,'0')
                                                                      END || TO_CHAR(P.DTMES,'MM/YYYY'),'DD/MM/YYYY'),1)-1
                              GROUP BY TO_DATE(CASE WHEN TO_NUMBER(:P_DIA) > TO_NUMBER(TO_CHAR(LAST_DAY(:P_DATA),'DD'))
                                                 THEN TO_CHAR(LAST_DAY(:P_DATA),'DD')
                                                 ELSE LPAD(:P_DIA,2,'0')
                                            END || TO_CHAR(P.DTMES,'MM/YYYY'),'DD/MM/YYYY'))";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "P_DIA"       => $params['DIA'],
                    "P_DATA"      => $params['DATA'],
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findDiaInicioOrcamento($cdFilialDestino)
    {
        try {
            $query = "SELECT IDCONSAFORCFIL, VRPEORCBLOQFIL, NVL(P.IDVERIORCFILI,'NAO_VALIDA') IDVERIORCFILI,
                            NVL(F.NRDIAINIORCAGOP,PO.NRDIAINIORCA) DIAINIORCA, NVL(PO.CDTIPOCUSTO,'03') CDTIPOCUSTO
                        FROM FILIAL F, PARASUPRI P, PARAMORCAOPERAC PO
                        WHERE F.CDFILIAL = :P_CDFILDEST
                        AND P.CDFILIAL = NVL(F.CDFILCENTCMP, F.CDFILIAL)
                        AND F.NRORG    = :P_NRORG
                        AND PO.NRORG   = :P_NRORG
                        AND F.NRORG    = P.NRORG";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "P_CDFILDEST" => $cdFilialDestino,
                    "P_NRORG"     => $this->environment->getNrOrg(),
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findPeriodoOrcamento($params)
    {
        try {
            $query = "SELECT MAX(NRPERIODO) V_NRPERIODOORCAGOP, MAX(IDPERIODOORCA) V_IDPERIODOORCA
                         FROM PERIODOORCAGOP P
                        WHERE P.NRORG = :P_NRORG
                          AND TO_DATE(:V_DATAINI) BETWEEN TO_DATE(CASE WHEN TO_NUMBER(:DIAINIORCA) > TO_NUMBER(TO_CHAR(LAST_DAY(:V_DATAINI),'DD'))
                                                             THEN TO_CHAR(LAST_DAY(:V_DATAINI),'DD')
                                                             ELSE LPAD(:DIAINIORCA,2,'0')
                                                       END || TO_CHAR(P.DTINIPERIORCA,'MM') || TO_CHAR(TO_DATE(:V_DATAINI), 'YYYY'),'DD/MM/YYYY')
                                            AND ADD_MONTHS(TO_DATE(CASE WHEN TO_NUMBER(:DIAINIORCA) > TO_NUMBER(TO_CHAR(LAST_DAY(:V_DATAINI),'DD'))
                                                                        THEN TO_CHAR(LAST_DAY(:V_DATAINI),'DD')
                                                                        ELSE LPAD(:DIAINIORCA,2,'0')
                                                                   END || TO_CHAR(P.DTFIMPERIORCA,'MM') || TO_CHAR(TO_DATE(:V_DATAINI), 'YYYY'),'DD/MM/YYYY'),1)-1";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "DIAINIORCA" => $params['DIAINIORCA'],
                    "V_DATAINI"  => $params['V_DATAINI'],
                    "P_NRORG"    => $this->environment->getNrOrg(),
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function findDataEntregaAF($params)
    {
        try {
            $query = "SELECT DTPROGENTAF
                       FROM ITEMAUTF AF
                      WHERE AF.CDFILDEST  = :P_CDFILDEST
                        AND AF.CDFILLANC  = :P_CDFILLANC
                        AND AF.NRAUTOFORN = :P_NRDEMANDA
                        AND AF.NRORG      = :P_NRORG
                      GROUP BY DTPROGENTAF";
            $std = $this->connection->prepare($query);
            $std->execute(
                array(
                    "P_CDFILDEST" => $params['CDFILDEST'],
                    "P_CDFILLANC" => $params['CDFILLANC'],
                    "P_NRDEMANDA" => $params['NRDEMANDA'],
                    "P_NRORG"     => $this->environment->getNrOrg(),
                )
            );
            
            return $std->fetchAll();
        } catch(\Exception $e) {
            throw $e;
        }
    }
}
