/*===-  Criação dos Types para Function  -===*/

DROP TYPE OM_ANALISE_COLETA_TABLE;
/

DROP TYPE OM_ANALISE_COLETA_TYPE;
/

CREATE OR REPLACE TYPE OM_ANALISE_COLETA_TYPE AS OBJECT
   (NRSEQCONTRATO       NUMBER,
	CONTRATO            VARCHAR2(100),
	NRPARCNEGOCIO       NUMBER,
	NMPARCEIRO          VARCHAR2(1000),
	ORGANIZACAOPARC     NUMBER, 
	IDTIPOORG           VARCHAR2(1),
	DTINICOMPET         DATE, 
	DTFINCOMPET         DATE,
	CDSERVORCA          NUMBER,
	NMSERVORCA          VARCHAR2(1000),
	IDELEMENTORAIZ      VARCHAR2(10), 
	NMELEMENTO          VARCHAR2(1000),
	DSTIPOELEMENTO      VARCHAR2(30), 
	CDTPMEDIDAVARIAVEL  NUMBER, 
	DSTPMEDIDASERV      VARCHAR2(100),
	PREPSTATUS          VARCHAR2(1), 
	NRORGPRINCIPAL      NUMBER,
	NMORGPRINCIPAL      VARCHAR2(250),
	QTCONTRATUAL        NUMBER,
	QTMEDIDA            NUMBER, 
	QTFATURADA          NUMBER, 
	DTULTIMACOLETAOM    DATE, 
	QTULTIMAMEDIDAOM    NUMBER,
	IDSTATUS            VARCHAR2(1),
	IDSEMERRO           VARCHAR2(1),
	DSOBSCOLETA         VARCHAR2(4000),
	SERVIDOR            VARCHAR2(500),  
	DSSTRINGCONEXAO     VARCHAR2(250), 
	IDUTWALLET          VARCHAR2(1), 
	IDCOLETOR           VARCHAR2(100),
	IDTPCOLETA          VARCHAR2(50),
	IDTPBANCO           VARCHAR2(25),
	IDLOCALCOLETOR      VARCHAR(1),
	SCRIPT_COUNT_SQL    CLOB,
	SCRIPT_LOG_SQL      CLOB,
	SCRIPT_COUNT_PHP    CLOB,
	SCRIPT_LOG_PHP      CLOB,
	DTINCLUSAOERRO      DATE,
	NRORG               NUMBER,
	DTINCLUSAO          DATE);
/

CREATE OR REPLACE TYPE OM_ANALISE_COLETA_TABLE AS TABLE OF OM_ANALISE_COLETA_TYPE;
/

/*===-  Criação da Function OM_ANALISE_COLETA  -===*/

CREATE OR REPLACE FUNCTION OM_ANALISE_COLETA(P_DTINICIO IN DATE,
                                             P_DTFINAL IN DATE,
											 P_NRORG IN FCT_CONTRATO.NRORG%TYPE)

/* P_TIPO: 'SERVICO' / 'PARCEIRO' / 'CONTRATO' / 'EXPORTACAO' */

RETURN OM_ANALISE_COLETA_TABLE PIPELINED
IS
OUT_RECORD OM_ANALISE_COLETA_TYPE := OM_ANALISE_COLETA_TYPE (NULL, NULL, NULL, NULL, NULL, NULL,
                                                             NULL, NULL, NULL, NULL, NULL, NULL,
                                                             NULL, NULL, NULL, NULL, NULL, NULL,
                                                             NULL, NULL, NULL, NULL, NULL, NULL,
															 NULL, NULL, NULL, NULL, NULL, NULL,
															 NULL, NULL, NULL, NULL, NULL, NULL,
															 NULL, NULL, NULL, NULL);

V_STATUS            VARCHAR2(1); /* E - Erro (Coleta Automatica) | W - Alerta (Parametrização) | A - Alerta (Coleta Automática) | O - Coleta OK  | X - Coleta OK (Erros em coletas Posteriores) */																								
V_DSTIPOELEMENTO    VARCHAR2(30);
V_PRODUCT_ID        OM_PRODUTO.NREXTERNAL_PRODUCT_ID%TYPE;
V_ORGANIZACAO     	NUMBER;	
V_IDTIPOORG         VARCHAR2(1);
V_DSOBSCOLETA       VARCHAR2(4000); 
V_DT_ULTIMO_ERRO    DATE;
V_ERRO_COLETA       ERROS_COLETA.ERRO_COLETA%TYPE;
V_PREPSTATUS        ORGANIZACAO.PREPSTATUS%TYPE;
V_NRORGPRINCIPAL    ORGANIZACAO.NRORGPRINCIPAL%TYPE; 
V_NMORGPRINCIPAL    ORGANIZACAO.NMRAZSOCIALORG%TYPE;

V_SERVIDOR          ERROS_COLETA.SERVIDOR%TYPE;  
V_DSSTRINGCONEXAO   ERROS_COLETA.DSSTRINGCONEXAO%TYPE; 
V_IDUTWALLET        ERROS_COLETA.IDUTWALLET%TYPE; 
V_IDCOLETOR         ERROS_COLETA.IDCOLETOR%TYPE;
V_IDTPBANCO         VARCHAR2(25);
V_IDLOCALCOLETOR    VARCHAR2(1);
V_SCRIPT_COUNT_SQL  CLOB;
V_SCRIPT_LOG_SQL    CLOB;
V_SCRIPT_COUNT_PHP  CLOB;
V_SCRIPT_LOG_PHP    CLOB;

BEGIN
	
	V_STATUS     := NULL;
	V_DSOBSCOLETA  := NULL;
	V_PRODUCT_ID := NULL;
	V_ERRO_COLETA := NULL;
	V_NMORGPRINCIPAL := NULL;
	
	V_SERVIDOR         := NULL;  
	V_DSSTRINGCONEXAO  := NULL; 
	V_IDUTWALLET       := NULL; 
	V_IDCOLETOR        := NULL;
	V_IDTPBANCO        := NULL;
	V_IDLOCALCOLETOR   := 1;
	
	V_SCRIPT_COUNT_SQL := NULL;
	V_SCRIPT_LOG_SQL   := NULL;
	V_SCRIPT_COUNT_PHP := NULL;
	V_SCRIPT_LOG_PHP   := NULL;
	
	FOR C_MEDICAO IN (SELECT MED.NRMEDICAOFATURA, MED.NRSEQCONTRATO, CONT.NRCONTRATOFCT, CONT.NRPARCNEGOCIO, PARC.NMPRINCIPALPARC, 
							 PARC.NMSECUNDARIPARC, MED.DTINICOMPET, MED.DTFINCOMPET, MEDVAR.IDELEMENTORAIZ, ELEM.NMSERVORCA AS NMELEMENTO,
							 ELEM.IDTIPOELEMENTO, MEDVAR.CDSERVORCA, SERV.NMSERVORCA, MEDVAR.CDTPMEDIDAVARIAVEL, TPMED.DSTPMEDIDASERV, TPMED.IDTPCOLETAMEDIDASERV,
							 MEDVAR.QTMEDIDAVENDIDA AS QTCONTRATUAL, MEDVAR.QTMEDIDAVARIAVEL AS QTMEDIDA, MEDVAR.QTMEDIDAMEDICAO AS QTFATURADA, MEDVAR.DTCOLETAVALIDAOM, MEDVAR.QTMEDIDAVALIDAOM, 
							 MEDVAR.DTULTIMACOLETAOM, MEDVAR.QTULTIMAMEDIDAOM
						FROM FCT_MEDVARMEDICAOFATURA MEDVAR
						JOIN FCT_MEDICAOFATURA MED
						  ON MED.NRMEDICAOFATURA = MEDVAR.NRMEDICAOFATURA
						 AND MED.NRORG = MEDVAR.NRORG
						JOIN FCT_CONTRATO CONT
						  ON CONT.NRSEQCONTRATO = MED.NRSEQCONTRATO
						 AND CONT.NRORG = MED.NRORG
						JOIN PARCNEGOCIO PARC
						  ON PARC.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
						 AND PARC.NRORG = CONT.NRORG
						JOIN FCT_SERVICOORCA ELEM
						  ON ELEM.IDELEMENTO = MEDVAR.IDELEMENTORAIZ
						 AND ELEM.NRORG = MEDVAR.NRORG
						JOIN FCT_SERVICOORCA SERV
						  ON SERV.CDSERVORCA = MEDVAR.CDSERVORCA
						 AND SERV.NRORG = MEDVAR.NRORG
						JOIN FCT_TIPOMEDIDASERV TPMED
						  ON TPMED.CDTPMEDIDASERV = MEDVAR.CDTPMEDIDAVARIAVEL
						 AND TPMED.NRORG = MEDVAR.NRORG
					   WHERE ((MED.DTINICOMPET BETWEEN P_DTINICIO AND P_DTFINAL) 
							  OR (MED.DTFINCOMPET BETWEEN P_DTINICIO AND P_DTFINAL))
						 AND MEDVAR.NRORG = P_NRORG
					   ORDER BY NRPARCNEGOCIO, NRSEQCONTRATO) LOOP
					   
		BEGIN
			SELECT NRORG, IDORGSAAS, PREPSTATUS, NRORGPRINCIPAL
			  INTO V_ORGANIZACAO, V_IDTIPOORG, V_PREPSTATUS, V_NRORGPRINCIPAL
			  FROM ORGANIZACAO
			 WHERE NRPARCNEGOCIO = C_MEDICAO.NRPARCNEGOCIO
			   AND IDATIVO = 'S';
		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				V_ORGANIZACAO := NULL;
				V_IDTIPOORG := NULL;
				V_PREPSTATUS := NULL;
				V_NRORGPRINCIPAL := NULL;
		END;
		
		IF(V_NRORGPRINCIPAL IS NOT NULL) THEN
			BEGIN
				SELECT NMRAZSOCIALORG
				  INTO V_NMORGPRINCIPAL
				  FROM ORGANIZACAO
				 WHERE NRORG = V_NRORGPRINCIPAL;
			EXCEPTION
				WHEN NO_DATA_FOUND THEN
					V_NMORGPRINCIPAL := NULL;
			END;
		END IF;

		IF (C_MEDICAO.IDTIPOELEMENTO = 'G') THEN
			
			V_DSTIPOELEMENTO := 'Produto (Criado no SM)';
			
			IF ((C_MEDICAO.QTMEDIDA IS NULL) OR (C_MEDICAO.QTMEDIDA = 0)) THEN
				
				/* Coleta dos elementos tipo "G" não realizada */
				  
				V_STATUS := 'W';
				V_DSOBSCOLETA := 'Elementos do tipo "Produto (Criado no SM)" não realizam coleta automática, uma vez que não estão vinculados no Modulo OM. Para estes produtos, deve ser realizada a medição de forma manual.';
			 	
			ELSE
			    /* Coleta dos elementos tipo "G" realizada */
				
				V_STATUS := 'O';
				V_DSOBSCOLETA :=  'Coleta realizada com sucesso.';
			
			END IF;
			
			/* GRAVA DADOS */
		
			/* 1- Dados do Contrato */
			OUT_RECORD.NRSEQCONTRATO       := C_MEDICAO.NRSEQCONTRATO;
			OUT_RECORD.CONTRATO            := C_MEDICAO.NRCONTRATOFCT;
			OUT_RECORD.NRPARCNEGOCIO       := C_MEDICAO.NRPARCNEGOCIO;
			OUT_RECORD.NMPARCEIRO          := C_MEDICAO.NMPRINCIPALPARC||' - ('||C_MEDICAO.NMSECUNDARIPARC||')';
			OUT_RECORD.ORGANIZACAOPARC     := V_ORGANIZACAO; 
			OUT_RECORD.IDTIPOORG           := V_IDTIPOORG;
			OUT_RECORD.DTINICOMPET         := C_MEDICAO.DTINICOMPET;
			OUT_RECORD.DTFINCOMPET         := C_MEDICAO.DTFINCOMPET;
			OUT_RECORD.CDSERVORCA          := C_MEDICAO.CDSERVORCA;
			OUT_RECORD.NMSERVORCA          := C_MEDICAO.NMSERVORCA;
			OUT_RECORD.IDELEMENTORAIZ      := SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ)); 
			OUT_RECORD.NMELEMENTO          := C_MEDICAO.NMELEMENTO;
			OUT_RECORD.DSTIPOELEMENTO      := V_DSTIPOELEMENTO; 
			OUT_RECORD.CDTPMEDIDAVARIAVEL  := C_MEDICAO.CDTPMEDIDAVARIAVEL; 
			OUT_RECORD.DSTPMEDIDASERV      := C_MEDICAO.DSTPMEDIDASERV;
			OUT_RECORD.PREPSTATUS          := V_PREPSTATUS;
			OUT_RECORD.NRORGPRINCIPAL      := V_NRORGPRINCIPAL;
			OUT_RECORD.NMORGPRINCIPAL      := V_NMORGPRINCIPAL;
			
			/* 2- Dados de Medição */
			OUT_RECORD.QTCONTRATUAL        := C_MEDICAO.QTCONTRATUAL;
			OUT_RECORD.QTMEDIDA            := C_MEDICAO.QTMEDIDA;
			OUT_RECORD.QTFATURADA          := C_MEDICAO.QTFATURADA;
			OUT_RECORD.DTULTIMACOLETAOM    := C_MEDICAO.DTULTIMACOLETAOM; 
			OUT_RECORD.QTULTIMAMEDIDAOM    := C_MEDICAO.QTULTIMAMEDIDAOM;
			
			/* 3- Dados da Situação */
			OUT_RECORD.IDSTATUS            := V_STATUS;
			IF (V_STATUS = 'O') THEN
				OUT_RECORD.IDSEMERRO       :=  'N';
			ELSE
				OUT_RECORD.IDSEMERRO       :=  'S';
			END IF;
			OUT_RECORD.DSOBSCOLETA         := V_DSOBSCOLETA;
			
			/* 4- Dados de Parametrização / Servidor */
			OUT_RECORD.IDLOCALCOLETOR      := V_IDLOCALCOLETOR;
			OUT_RECORD.SERVIDOR            := V_SERVIDOR;  
			OUT_RECORD.DSSTRINGCONEXAO     := REPLACE(V_DSSTRINGCONEXAO, '[NRORG]', V_ORGANIZACAO);  
			OUT_RECORD.IDUTWALLET          := V_IDUTWALLET; 
			OUT_RECORD.IDCOLETOR           := V_IDCOLETOR;
			OUT_RECORD.IDTPBANCO           := V_IDTPBANCO;
			OUT_RECORD.IDTPCOLETA          := C_MEDICAO.IDTPCOLETAMEDIDASERV;
			OUT_RECORD.SCRIPT_COUNT_SQL    := V_SCRIPT_COUNT_SQL;
			OUT_RECORD.SCRIPT_LOG_SQL      := V_SCRIPT_LOG_SQL;
			OUT_RECORD.SCRIPT_COUNT_PHP    := V_SCRIPT_COUNT_PHP;
			OUT_RECORD.SCRIPT_LOG_PHP      := V_SCRIPT_LOG_PHP;
			OUT_RECORD.DTINCLUSAOERRO      := NULL;
			
			/*5- NRORG E Data de Inclusão*/
			OUT_RECORD.NRORG               := P_NRORG;
			OUT_RECORD.DTINCLUSAO          := SYSDATE;

			PIPE ROW (OUT_RECORD);
		
		ELSE 
			
			V_DSTIPOELEMENTO := 'Produto';
			
			IF (C_MEDICAO.DTULTIMACOLETAOM IS NOT NULL) THEN
				/* Houve coleta com sucesso no período. 
				
				   Neste caso verificamos se existe registro na tabela de erros de coleta. 
					- Se não houver, colocamos a situação como "Coleta OK".
					- Se houver, verificamos se os registros foram posteriores à ultima coleta válida do OM. 
						- Caso positivo, colocamos a Situação como "Coleta OK (Erros em coletas Posteriores)"
						- Caso negativo, colocamos a Situação como "Coleta OK" */
				
				BEGIN
					SELECT NREXTERNAL_PRODUCT_ID 
					  INTO V_PRODUCT_ID
					  FROM OM_PRODUTO
					 WHERE ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));
				EXCEPTION
					WHEN NO_DATA_FOUND THEN
						V_PRODUCT_ID := NULL;
				END;
				
				BEGIN
				   SELECT MAX(ECL.DTINCLUSAO) AS DT_ULTIMO_ERRO
					 INTO V_DT_ULTIMO_ERRO
					 FROM ERROS_COLETA ECL
					 JOIN ORGANIZACAO ORG        
					   ON ORG.NRORG = ECL.NRORG_ID
					 JOIN FCT_TIPOMEDIDASERV TPM 
					   ON TPM.CDTPMEDIDASERV = ECL.CDTPMEDIDASERV
					 JOIN FCT_CONTRATO CTR       
					   ON CTR.NRSEQCONTRATO = ECL.NRSEQCONTRATO
				LEFT JOIN FCT_SERVICOORCA SEO    
					   ON SEO.CDSERVORCA = ECL.CDSERVORCA
				LEFT JOIN PRODUCT PRO           
					   ON PRO.ID = ECL.PRODUCT_ID
				LEFT JOIN ORGANIZACAO ORP        
					   ON ORG.NRORGPRINCIPAL = ORP.NRORG
					WHERE ECL.NRSEQCONTRATO = C_MEDICAO.NRSEQCONTRATO
					  AND ECL.CDSERVORCA = C_MEDICAO.CDSERVORCA
					  AND ECL.PRODUCT_ID = V_PRODUCT_ID
					  AND ECL.CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
					  AND ((ECL.DTINICOMPET BETWEEN P_DTINICIO AND P_DTFINAL) 
						   OR (ECL.DTFINCOMPET BETWEEN P_DTINICIO AND P_DTFINAL));
				EXCEPTION
					WHEN NO_DATA_FOUND THEN
						V_DT_ULTIMO_ERRO := NULL;
				END;
				
				IF ((V_DT_ULTIMO_ERRO IS NULL) OR (V_DT_ULTIMO_ERRO <= C_MEDICAO.DTULTIMACOLETAOM)) THEN
					
					V_STATUS := 'O';
					V_DSOBSCOLETA :=  'Coleta realizada com sucesso.';
					
					/* Serão verificados as parametrizações, scripts de coleta, etc...	*/
					
					/* 1 - Busca coletor:  Produto da organização */
					BEGIN
						SELECT OMPCOL.DSSTRINGCONEXAO, OMPCOL.IDCOLETOR, OMPCOL.IDUTWALLET, OMPCOL.IDTPBANCO, 
						       DECODE(OMPCOL.DSSTRINGCONEXAO, NULL, NULL, 2) AS IDLOCALCOLETOR
						  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR 
						  FROM OM_PRODUTO_ORG_COLETOR OMPCOL
						  JOIN OM_PRODUTO_ORG OMP
							ON OMPCOL.NRPRODUTO_ORG_ID = OMP.ID
						 WHERE OMP.NRORG_ID = V_ORGANIZACAO
						   AND OMP.NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));
					EXCEPTION
						WHEN NO_DATA_FOUND THEN BEGIN
							V_DSSTRINGCONEXAO := NULL;
							V_IDCOLETOR := NULL;
							V_IDUTWALLET := NULL;
							V_IDTPBANCO := NULL;
							V_IDLOCALCOLETOR := 1;
						END;
					END;
					
					IF (V_DSSTRINGCONEXAO IS NULL) THEN
						
						/* 2 - Busca coletor:  Organização */
						BEGIN
							SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
							       DECODE(DSSTRINGCONEXAO, NULL, NULL, 3) AS IDLOCALCOLETOR
							  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
							  FROM OM_PARAM_ORG
							 WHERE NRORG =  V_ORGANIZACAO;
						EXCEPTION
							WHEN NO_DATA_FOUND THEN BEGIN
								V_DSSTRINGCONEXAO := NULL;
								V_IDCOLETOR := NULL;
								V_IDUTWALLET := NULL;
								V_IDTPBANCO := NULL;
								V_IDLOCALCOLETOR := 1;
							END;
						END;
						
						IF (V_DSSTRINGCONEXAO IS NULL) THEN
						
							/* 3 - Busca coletor:  Produto (Parametrização) */
							BEGIN
								SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
									   DECODE(DSSTRINGCONEXAO, NULL, NULL, 4) AS IDLOCALCOLETOR
									   INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
								  FROM OM_PRODUTO_COLETOR
								 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));

							EXCEPTION
								WHEN NO_DATA_FOUND THEN BEGIN
									V_DSSTRINGCONEXAO := NULL;
									V_IDCOLETOR := NULL;
									V_IDUTWALLET := NULL;
									V_IDTPBANCO := NULL;
									V_IDLOCALCOLETOR := 1;
								END;
							END;
							
							IF (V_DSSTRINGCONEXAO IS NULL) THEN
								
								/* 4 - Busca coletor:  Parametro por Hospedagem */
								BEGIN
									SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
										   DECODE(DSSTRINGCONEXAO, NULL, NULL, 5) AS IDLOCALCOLET
									  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
									  FROM OM_PARAM_ORG_DEFAULT
									 WHERE IDAMBORG = V_IDTIPOORG;
								EXCEPTION
									WHEN NO_DATA_FOUND THEN BEGIN
										V_DSSTRINGCONEXAO := NULL;
										V_IDCOLETOR := NULL;
										V_IDUTWALLET := NULL;
										V_IDTPBANCO := NULL;
										V_IDLOCALCOLETOR := 1;
									END;
								END;
								
							END IF;
						
						END IF;
					
					END IF;
					
					
					/* Busca Script Coleta */
					
					/*PHP*/
					
					BEGIN	
						SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
						  INTO V_SCRIPT_COUNT_PHP, V_SCRIPT_LOG_PHP
						  FROM OM_CONFIG_MEDIDA_VARIAVEL
						 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
						   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
					       AND IDTPSCRIPT = 'PHP';
					EXCEPTION
						WHEN NO_DATA_FOUND THEN BEGIN
							V_SCRIPT_COUNT_PHP := NULL;
							V_SCRIPT_LOG_PHP   := NULL;
						END;
					END;
					
					/*SQL*/
					
					BEGIN	
						SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
						  INTO V_SCRIPT_COUNT_SQL, V_SCRIPT_LOG_SQL
						  FROM OM_CONFIG_MEDIDA_VARIAVEL
						 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
						   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
					       AND IDTPSCRIPT = 'SQL';
					EXCEPTION
						WHEN NO_DATA_FOUND THEN BEGIN
							V_SCRIPT_COUNT_SQL := NULL;
							V_SCRIPT_LOG_SQL   := NULL;
						END;
					END;
					
					/* GRAVA DADOS */
		
					/* 1- Dados do Contrato */
					OUT_RECORD.NRSEQCONTRATO       := C_MEDICAO.NRSEQCONTRATO;
					OUT_RECORD.CONTRATO            := C_MEDICAO.NRCONTRATOFCT;
					OUT_RECORD.NRPARCNEGOCIO       := C_MEDICAO.NRPARCNEGOCIO;
					OUT_RECORD.NMPARCEIRO          := C_MEDICAO.NMPRINCIPALPARC||' - ('||C_MEDICAO.NMSECUNDARIPARC||')';
					OUT_RECORD.ORGANIZACAOPARC     := V_ORGANIZACAO; 
					OUT_RECORD.IDTIPOORG           := V_IDTIPOORG;
					OUT_RECORD.DTINICOMPET         := C_MEDICAO.DTINICOMPET;
					OUT_RECORD.DTFINCOMPET         := C_MEDICAO.DTFINCOMPET;
					OUT_RECORD.CDSERVORCA          := C_MEDICAO.CDSERVORCA;
					OUT_RECORD.NMSERVORCA          := C_MEDICAO.NMSERVORCA;
					OUT_RECORD.IDELEMENTORAIZ      := SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ)); 
					OUT_RECORD.NMELEMENTO          := C_MEDICAO.NMELEMENTO;
					OUT_RECORD.DSTIPOELEMENTO      := V_DSTIPOELEMENTO; 
					OUT_RECORD.CDTPMEDIDAVARIAVEL  := C_MEDICAO.CDTPMEDIDAVARIAVEL; 
					OUT_RECORD.DSTPMEDIDASERV      := C_MEDICAO.DSTPMEDIDASERV;
					OUT_RECORD.PREPSTATUS          := V_PREPSTATUS;
					OUT_RECORD.NRORGPRINCIPAL      := V_NRORGPRINCIPAL;
					OUT_RECORD.NMORGPRINCIPAL      := V_NMORGPRINCIPAL;
					
					/* 2- Dados de Medição */
					OUT_RECORD.QTCONTRATUAL        := C_MEDICAO.QTCONTRATUAL;
					OUT_RECORD.QTMEDIDA            := C_MEDICAO.QTMEDIDA;
					OUT_RECORD.QTFATURADA          := C_MEDICAO.QTFATURADA;
					OUT_RECORD.DTULTIMACOLETAOM    := C_MEDICAO.DTULTIMACOLETAOM; 
					OUT_RECORD.QTULTIMAMEDIDAOM    := C_MEDICAO.QTULTIMAMEDIDAOM;
					
					/* 3- Dados da Situação */
					OUT_RECORD.IDSTATUS            := V_STATUS;
					IF (V_STATUS = 'O') THEN
						OUT_RECORD.IDSEMERRO       :=  'N';
					ELSE
						OUT_RECORD.IDSEMERRO       :=  'S';
					END IF;
					OUT_RECORD.DSOBSCOLETA         := V_DSOBSCOLETA;
					
					/* 4- Dados de Parametrização / Servidor */
					OUT_RECORD.IDLOCALCOLETOR      := V_IDLOCALCOLETOR;
					OUT_RECORD.SERVIDOR            := V_SERVIDOR;  
					OUT_RECORD.DSSTRINGCONEXAO     := REPLACE(V_DSSTRINGCONEXAO, '[NRORG]', V_ORGANIZACAO); 
					OUT_RECORD.IDUTWALLET          := V_IDUTWALLET; 
					OUT_RECORD.IDCOLETOR           := V_IDCOLETOR;
					OUT_RECORD.IDTPBANCO           := V_IDTPBANCO;
					OUT_RECORD.IDTPCOLETA          := C_MEDICAO.IDTPCOLETAMEDIDASERV;
					OUT_RECORD.SCRIPT_COUNT_SQL    := V_SCRIPT_COUNT_SQL;
					OUT_RECORD.SCRIPT_LOG_SQL      := V_SCRIPT_LOG_SQL;
					OUT_RECORD.SCRIPT_COUNT_PHP    := V_SCRIPT_COUNT_PHP;
					OUT_RECORD.SCRIPT_LOG_PHP      := V_SCRIPT_LOG_PHP;
					OUT_RECORD.DTINCLUSAOERRO      := NULL;
					
					/*5- NRORG E Data de Inclusão*/
					OUT_RECORD.NRORG               := P_NRORG;
					OUT_RECORD.DTINCLUSAO          := SYSDATE;

					PIPE ROW (OUT_RECORD);
					
				ELSE
				
					FOR C_ERROS1 IN (SELECT ECL.ERRO_COLETA, ECL.DSSTRINGCONEXAO, ECL.IDUTWALLET, ECL.IDCOLETOR, ECL.IDTPERRO, ECL.DTINCLUSAO,
										    NVL(ECL.SCRIPT_COUNT_PHP, DECODE(ECL.IDTPSCRIPT, 'PHP', ECL.SCRIPT_COUNT, NULL)) AS SCRIPT_COUNT_PHP, 
										    NVL(ECL.SCRIPT_LOG_PHP, DECODE(ECL.IDTPSCRIPT, 'PHP', ECL.SCRIPT_LOG, NULL)) AS SCRIPT_LOG_PHP, 
										    NVL(ECL.SCRIPT_COUNT_SQL, DECODE(ECL.IDTPSCRIPT, 'SQL', ECL.SCRIPT_COUNT, NULL)) AS SCRIPT_COUNT_SQL, 
										    NVL(ECL.SCRIPT_LOG_SQL, DECODE(ECL.IDTPSCRIPT, 'SQL', ECL.SCRIPT_LOG, NULL)) AS SCRIPT_LOG_SQL 
									   FROM ERROS_COLETA ECL
									   JOIN ORGANIZACAO ORG        
										 ON ORG.NRORG = ECL.NRORG_ID
									   JOIN FCT_TIPOMEDIDASERV TPM 
										 ON TPM.CDTPMEDIDASERV = ECL.CDTPMEDIDASERV
									   JOIN FCT_CONTRATO CTR       
										 ON CTR.NRSEQCONTRATO = ECL.NRSEQCONTRATO
									   LEFT JOIN FCT_SERVICOORCA SEO    
										 ON SEO.CDSERVORCA = ECL.CDSERVORCA
									   LEFT JOIN PRODUCT PRO           
										 ON PRO.ID = ECL.PRODUCT_ID
									   LEFT JOIN ORGANIZACAO ORP        
										 ON ORG.NRORGPRINCIPAL = ORP.NRORG
									  WHERE ECL.NRSEQCONTRATO = C_MEDICAO.NRSEQCONTRATO
										AND ECL.CDSERVORCA = C_MEDICAO.CDSERVORCA
										AND ECL.PRODUCT_ID = V_PRODUCT_ID
										AND ECL.CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
										AND ((ECL.DTINICOMPET BETWEEN P_DTINICIO AND P_DTFINAL) 
											 OR (ECL.DTFINCOMPET BETWEEN P_DTINICIO AND P_DTFINAL))
										AND ECL.DTINCLUSAO >= C_MEDICAO.DTULTIMACOLETAOM) LOOP
						
						
						V_DSSTRINGCONEXAO  := C_ERROS1.DSSTRINGCONEXAO;
						V_IDUTWALLET       := C_ERROS1.IDUTWALLET; 
						V_IDCOLETOR        := C_ERROS1.IDCOLETOR; 
						V_SCRIPT_COUNT_PHP := C_ERROS1.SCRIPT_COUNT_PHP; 
						V_SCRIPT_LOG_PHP   := C_ERROS1.SCRIPT_LOG_PHP; 
						V_SCRIPT_COUNT_SQL := C_ERROS1.SCRIPT_COUNT_SQL; 
						V_SCRIPT_LOG_SQL   := C_ERROS1.SCRIPT_LOG_SQL;
					
						V_STATUS := 'X';
						
						V_DSOBSCOLETA :=  'A coleta deste produto já foi realizada com sucesso para o período. Porém, posteriormente à coleta realizada com sucesso, ocorreram falhas na mesma. Falhas: '||C_ERROS1.ERRO_COLETA;
						
						/* Serão verificados as parametrizações, scripts de coleta, etc...	 
							OBS: Nesse caso, o script será considerdo o da tabela de erro. */
						IF (V_DSSTRINGCONEXAO IS NULL) THEN
							
							/* 1 - Busca coletor:  Produto da organização */
							BEGIN
								SELECT OMPCOL.DSSTRINGCONEXAO, OMPCOL.IDCOLETOR, OMPCOL.IDUTWALLET, OMPCOL.IDTPBANCO, 
									   DECODE(OMPCOL.DSSTRINGCONEXAO, NULL, NULL, 2) AS IDLOCALCOLETOR
								  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR 
								  FROM OM_PRODUTO_ORG_COLETOR OMPCOL
								  JOIN OM_PRODUTO_ORG OMP
									ON OMPCOL.NRPRODUTO_ORG_ID = OMP.ID
								 WHERE OMP.NRORG_ID = V_ORGANIZACAO
								   AND OMP.NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));
							EXCEPTION
								WHEN NO_DATA_FOUND THEN BEGIN
									V_DSSTRINGCONEXAO := NULL;
									V_IDCOLETOR := NULL;
									V_IDUTWALLET := NULL;
									V_IDTPBANCO := NULL;
									V_IDLOCALCOLETOR := 1;
								END;
							END;
							
							IF (V_DSSTRINGCONEXAO IS NULL) THEN
								
								/* 2 - Busca coletor:  Organização */
								BEGIN
									SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
										   DECODE(DSSTRINGCONEXAO, NULL, NULL, 3) AS IDLOCALCOLETOR
									  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
									  FROM OM_PARAM_ORG
									 WHERE NRORG =  V_ORGANIZACAO;
								EXCEPTION
									WHEN NO_DATA_FOUND THEN BEGIN
										V_DSSTRINGCONEXAO := NULL;
										V_IDCOLETOR := NULL;
										V_IDUTWALLET := NULL;
										V_IDTPBANCO := NULL;
										V_IDLOCALCOLETOR := 1;
									END;
								END;
								
								IF (V_DSSTRINGCONEXAO IS NULL) THEN
								
									/* 3 - Busca coletor:  Produto (Parametrização) */
									BEGIN
										SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
											   DECODE(DSSTRINGCONEXAO, NULL, NULL, 4) AS IDLOCALCOLETOR
											   INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
										  FROM OM_PRODUTO_COLETOR
										 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));

									EXCEPTION
										WHEN NO_DATA_FOUND THEN BEGIN
											V_DSSTRINGCONEXAO := NULL;
											V_IDCOLETOR := NULL;
											V_IDUTWALLET := NULL;
											V_IDTPBANCO := NULL;
											V_IDLOCALCOLETOR := 1;
										END;
									END;
									
									IF (V_DSSTRINGCONEXAO IS NULL) THEN
										
										/* 4 - Busca coletor:  Parametro por Hospedagem */
										BEGIN
											SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
												   DECODE(DSSTRINGCONEXAO, NULL, NULL, 5) AS IDLOCALCOLET
											  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
											  FROM OM_PARAM_ORG_DEFAULT
											 WHERE IDAMBORG = V_IDTIPOORG;
										EXCEPTION
											WHEN NO_DATA_FOUND THEN BEGIN
												V_DSSTRINGCONEXAO := NULL;
												V_IDCOLETOR := NULL;
												V_IDUTWALLET := NULL;
												V_IDTPBANCO := NULL;
												V_IDLOCALCOLETOR := 1;
											END;
										END;
										
										IF (V_DSSTRINGCONEXAO IS NULL) THEN
										
											IF (V_IDTIPOORG = 'N') THEN
												
												V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrada uma parametrização de coleta para o produto e/ou organização. A Organização desta coleta é do tipo "Local", neste caso, deve ser verificado se o coletor está instalado no cliente corretamente.';
											ELSE 
												V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrada uma parametrização de coleta para o produto e/ou organização.';
											END IF;
										
										END IF;
										
									END IF;
								
								END IF;
							
							END IF;
						ELSE
							IF (V_IDTIPOORG = 'N') THEN
												
								V_DSOBSCOLETA := V_DSOBSCOLETA||' | A Organização desta coleta é do tipo "Local", neste caso, deve ser verificado se o coletor está instalado no cliente corretamente.';
							END IF;
						END IF;
						
						/* Busca Script Coleta */
							
						/*PHP*/
						IF (V_SCRIPT_COUNT_PHP IS NULL) THEN
				
							BEGIN	
								SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
								  INTO V_SCRIPT_COUNT_PHP, V_SCRIPT_LOG_PHP
								  FROM OM_CONFIG_MEDIDA_VARIAVEL
								 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
								   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
								   AND IDTPSCRIPT = 'PHP';
							EXCEPTION
								WHEN NO_DATA_FOUND THEN BEGIN
									V_SCRIPT_COUNT_PHP := NULL;
									V_SCRIPT_LOG_PHP   := NULL;
								END;
							END;
							
						END IF;
						
						/*SQL*/
						
						IF (V_SCRIPT_COUNT_SQL IS NULL) THEN
						
							BEGIN	
								SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
								  INTO V_SCRIPT_COUNT_SQL, V_SCRIPT_LOG_SQL
								  FROM OM_CONFIG_MEDIDA_VARIAVEL
								 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
								   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
								   AND IDTPSCRIPT = 'SQL';
							EXCEPTION
								WHEN NO_DATA_FOUND THEN BEGIN
									V_SCRIPT_COUNT_SQL := NULL;
									V_SCRIPT_LOG_SQL   := NULL;
								END;
							END;
							
						END IF;
						
						IF ((V_SCRIPT_COUNT_PHP IS NULL) AND (V_SCRIPT_COUNT_SQL IS NULL)) THEN
						
							V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrado nenhum script cadastrado para o produto "'||C_MEDICAO.NMELEMENTO||'" com a medida "'||C_MEDICAO.DSTPMEDIDASERV||'"';
						
						END IF;
						
						/* GRAVA DADOS */
		
						/* 1- Dados do Contrato */
						OUT_RECORD.NRSEQCONTRATO       := C_MEDICAO.NRSEQCONTRATO;
						OUT_RECORD.CONTRATO            := C_MEDICAO.NRCONTRATOFCT;
						OUT_RECORD.NRPARCNEGOCIO       := C_MEDICAO.NRPARCNEGOCIO;
						OUT_RECORD.NMPARCEIRO          := C_MEDICAO.NMPRINCIPALPARC||' - ('||C_MEDICAO.NMSECUNDARIPARC||')';
						OUT_RECORD.ORGANIZACAOPARC     := V_ORGANIZACAO; 
						OUT_RECORD.IDTIPOORG           := V_IDTIPOORG;
						OUT_RECORD.DTINICOMPET         := C_MEDICAO.DTINICOMPET;
						OUT_RECORD.DTFINCOMPET         := C_MEDICAO.DTFINCOMPET;
						OUT_RECORD.CDSERVORCA          := C_MEDICAO.CDSERVORCA;
						OUT_RECORD.NMSERVORCA          := C_MEDICAO.NMSERVORCA;
						OUT_RECORD.IDELEMENTORAIZ      := SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ)); 
						OUT_RECORD.NMELEMENTO          := C_MEDICAO.NMELEMENTO;
						OUT_RECORD.DSTIPOELEMENTO      := V_DSTIPOELEMENTO; 
						OUT_RECORD.CDTPMEDIDAVARIAVEL  := C_MEDICAO.CDTPMEDIDAVARIAVEL; 
						OUT_RECORD.DSTPMEDIDASERV      := C_MEDICAO.DSTPMEDIDASERV;
						OUT_RECORD.PREPSTATUS          := V_PREPSTATUS;
						OUT_RECORD.NRORGPRINCIPAL      := V_NRORGPRINCIPAL;
						OUT_RECORD.NMORGPRINCIPAL      := V_NMORGPRINCIPAL;
						
						/* 2- Dados de Medição */
						OUT_RECORD.QTCONTRATUAL        := C_MEDICAO.QTCONTRATUAL;
						OUT_RECORD.QTMEDIDA            := C_MEDICAO.QTMEDIDA;
						OUT_RECORD.QTFATURADA          := C_MEDICAO.QTFATURADA;
						OUT_RECORD.DTULTIMACOLETAOM    := C_MEDICAO.DTULTIMACOLETAOM; 
						OUT_RECORD.QTULTIMAMEDIDAOM    := C_MEDICAO.QTULTIMAMEDIDAOM;
						
						/* 3- Dados da Situação */
						OUT_RECORD.IDSTATUS            := V_STATUS;
						IF (V_STATUS = 'O') THEN
							OUT_RECORD.IDSEMERRO       :=  'N';
						ELSE
							OUT_RECORD.IDSEMERRO       :=  'S';
						END IF;
						OUT_RECORD.DSOBSCOLETA         := V_DSOBSCOLETA;
						
						/* 4- Dados de Parametrização / Servidor */
						OUT_RECORD.IDLOCALCOLETOR      := V_IDLOCALCOLETOR;
						OUT_RECORD.SERVIDOR            := V_SERVIDOR;  
						OUT_RECORD.DSSTRINGCONEXAO     := REPLACE(V_DSSTRINGCONEXAO, '[NRORG]', V_ORGANIZACAO);  
						OUT_RECORD.IDUTWALLET          := V_IDUTWALLET; 
						OUT_RECORD.IDCOLETOR           := V_IDCOLETOR;
						OUT_RECORD.IDTPBANCO           := V_IDTPBANCO;
						OUT_RECORD.IDTPCOLETA          := C_MEDICAO.IDTPCOLETAMEDIDASERV;
						OUT_RECORD.SCRIPT_COUNT_SQL    := V_SCRIPT_COUNT_SQL;
						OUT_RECORD.SCRIPT_LOG_SQL      := V_SCRIPT_LOG_SQL;
						OUT_RECORD.SCRIPT_COUNT_PHP    := V_SCRIPT_COUNT_PHP;
						OUT_RECORD.SCRIPT_LOG_PHP      := V_SCRIPT_LOG_PHP;
						OUT_RECORD.DTINCLUSAOERRO      := C_ERROS1.DTINCLUSAO;
						
						/*5- NRORG E Data de Inclusão*/
						OUT_RECORD.NRORG               := P_NRORG;
						OUT_RECORD.DTINCLUSAO          := SYSDATE;

						PIPE ROW (OUT_RECORD);
						
					END LOOP;
				END IF;
				
			ELSE 
				
				FOR C_ERROS2 IN (SELECT ECL.ERRO_COLETA, ECL.DSSTRINGCONEXAO, ECL.IDUTWALLET, ECL.IDCOLETOR, ECL.IDTPERRO, ECL.DTINCLUSAO,
										    NVL(ECL.SCRIPT_COUNT_PHP, DECODE(ECL.IDTPSCRIPT, 'PHP', ECL.SCRIPT_COUNT, NULL)) AS SCRIPT_COUNT_PHP, 
										    NVL(ECL.SCRIPT_LOG_PHP, DECODE(ECL.IDTPSCRIPT, 'PHP', ECL.SCRIPT_LOG, NULL)) AS SCRIPT_LOG_PHP, 
										    NVL(ECL.SCRIPT_COUNT_SQL, DECODE(ECL.IDTPSCRIPT, 'SQL', ECL.SCRIPT_COUNT, NULL)) AS SCRIPT_COUNT_SQL, 
										    NVL(ECL.SCRIPT_LOG_SQL, DECODE(ECL.IDTPSCRIPT, 'SQL', ECL.SCRIPT_LOG, NULL)) AS SCRIPT_LOG_SQL 
									   FROM ERROS_COLETA ECL
									   JOIN ORGANIZACAO ORG        
										 ON ORG.NRORG = ECL.NRORG_ID
									   JOIN FCT_TIPOMEDIDASERV TPM 
										 ON TPM.CDTPMEDIDASERV = ECL.CDTPMEDIDASERV
									   JOIN FCT_CONTRATO CTR       
										 ON CTR.NRSEQCONTRATO = ECL.NRSEQCONTRATO
									   LEFT JOIN FCT_SERVICOORCA SEO    
										 ON SEO.CDSERVORCA = ECL.CDSERVORCA
									   LEFT JOIN PRODUCT PRO           
										 ON PRO.ID = ECL.PRODUCT_ID
									   LEFT JOIN ORGANIZACAO ORP        
										 ON ORG.NRORGPRINCIPAL = ORP.NRORG
									  WHERE ECL.NRSEQCONTRATO = C_MEDICAO.NRSEQCONTRATO
										AND ECL.CDSERVORCA = C_MEDICAO.CDSERVORCA
										AND ECL.PRODUCT_ID = V_PRODUCT_ID
										AND ECL.CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
										AND ((ECL.DTINICOMPET BETWEEN P_DTINICIO AND P_DTFINAL) 
											 OR (ECL.DTFINCOMPET BETWEEN P_DTINICIO AND P_DTFINAL))) LOOP
				
					V_DSSTRINGCONEXAO  := C_ERROS2.DSSTRINGCONEXAO;
					V_IDUTWALLET       := C_ERROS2.IDUTWALLET; 
					V_IDCOLETOR        := C_ERROS2.IDCOLETOR; 
					V_SCRIPT_COUNT_PHP := C_ERROS2.SCRIPT_COUNT_PHP; 
					V_SCRIPT_LOG_PHP   := C_ERROS2.SCRIPT_LOG_PHP; 
					V_SCRIPT_COUNT_SQL := C_ERROS2.SCRIPT_COUNT_SQL; 
					V_SCRIPT_LOG_SQL   := C_ERROS2.SCRIPT_LOG_SQL;
						
					V_STATUS := C_ERROS2.IDTPERRO;	
					
					IF (C_ERROS2.IDTPERRO = 'E') THEN
						V_DSOBSCOLETA  := 'Ocorreram erros na coleta deste produto. Erros: '||C_ERROS2.ERRO_COLETA;
					ELSE 
						V_DSOBSCOLETA  := 'Existem problemmas na parametrização que estão impactando na coleta deste produto. Falhas: '||C_ERROS2.ERRO_COLETA;
					END IF;
					
					/* Serão verificados as parametrizações, scripts de coleta, etc...	 
						OBS: Nesse caso, o script será considerdo o da tabela de erro. */
						
					IF (V_DSSTRINGCONEXAO IS NULL) THEN
						
						/* 1 - Busca coletor:  Produto da organização */
						BEGIN
							SELECT OMPCOL.DSSTRINGCONEXAO, OMPCOL.IDCOLETOR, OMPCOL.IDUTWALLET, OMPCOL.IDTPBANCO, 
								   DECODE(OMPCOL.DSSTRINGCONEXAO, NULL, NULL, 2) AS IDLOCALCOLETOR
							  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR 
							  FROM OM_PRODUTO_ORG_COLETOR OMPCOL
							  JOIN OM_PRODUTO_ORG OMP
								ON OMPCOL.NRPRODUTO_ORG_ID = OMP.ID
							 WHERE OMP.NRORG_ID = V_ORGANIZACAO
							   AND OMP.NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));
						EXCEPTION
							WHEN NO_DATA_FOUND THEN BEGIN
								V_DSSTRINGCONEXAO := NULL;
								V_IDCOLETOR := NULL;
								V_IDUTWALLET := NULL;
								V_IDTPBANCO := NULL;
								V_IDLOCALCOLETOR := 1;
							END;
						END;
						
						IF (V_DSSTRINGCONEXAO IS NULL) THEN
							
							/* 2 - Busca coletor:  Organização */
							BEGIN
								SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
									   DECODE(DSSTRINGCONEXAO, NULL, NULL, 3) AS IDLOCALCOLETOR
								  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
								  FROM OM_PARAM_ORG
								 WHERE NRORG =  V_ORGANIZACAO;
							EXCEPTION
								WHEN NO_DATA_FOUND THEN BEGIN
									V_DSSTRINGCONEXAO := NULL;
									V_IDCOLETOR := NULL;
									V_IDUTWALLET := NULL;
									V_IDTPBANCO := NULL;
									V_IDLOCALCOLETOR := 1;
								END;
							END;
							
							IF (V_DSSTRINGCONEXAO IS NULL) THEN
							
								/* 3 - Busca coletor:  Produto (Parametrização) */
								BEGIN
									SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
										   DECODE(DSSTRINGCONEXAO, NULL, NULL, 4) AS IDLOCALCOLETOR
										   INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
									  FROM OM_PRODUTO_COLETOR
									 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ));

								EXCEPTION
									WHEN NO_DATA_FOUND THEN BEGIN
										V_DSSTRINGCONEXAO := NULL;
										V_IDCOLETOR := NULL;
										V_IDUTWALLET := NULL;
										V_IDTPBANCO := NULL;
										V_IDLOCALCOLETOR := 1;
									END;
								END;
								
								IF (V_DSSTRINGCONEXAO IS NULL) THEN
									
									/* 4 - Busca coletor:  Parametro por Hospedagem */
									BEGIN
										SELECT DSSTRINGCONEXAO, IDCOLETOR, IDUTWALLET, IDTPBANCO, 
											   DECODE(DSSTRINGCONEXAO, NULL, NULL, 5) AS IDLOCALCOLET
										  INTO V_DSSTRINGCONEXAO, V_IDCOLETOR, V_IDUTWALLET, V_IDTPBANCO, V_IDLOCALCOLETOR
										  FROM OM_PARAM_ORG_DEFAULT
										 WHERE IDAMBORG = V_IDTIPOORG;
									EXCEPTION
										WHEN NO_DATA_FOUND THEN BEGIN
											V_DSSTRINGCONEXAO := NULL;
											V_IDCOLETOR := NULL;
											V_IDUTWALLET := NULL;
											V_IDTPBANCO := NULL;
											V_IDLOCALCOLETOR := 1;
										END;
									END;
									
									IF (V_DSSTRINGCONEXAO IS NULL) THEN
									
										IF (V_IDTIPOORG = 'N') THEN
											
											V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrada uma parametrização de coleta para o produto e/ou organização. A Organização desta coleta é do tipo "Local", neste caso, deve ser verificado se o coletor está instalado no cliente corretamente.';
										ELSE 
											V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrada uma parametrização de coleta para o produto e/ou organização.';
										END IF;
									
									END IF;
									
								END IF;
							
							END IF;
						
						END IF;
					ELSE
						IF (V_IDTIPOORG = 'N') THEN
											
							V_DSOBSCOLETA := V_DSOBSCOLETA||' | A Organização desta coleta é do tipo "Local", neste caso, deve ser verificado se o coletor está instalado no cliente corretamente.';
						END IF;
					END IF;
					
					/* Busca Script Coleta */
						
					/*PHP*/
					IF (V_SCRIPT_COUNT_PHP IS NULL) THEN
			
						BEGIN	
							SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
							  INTO V_SCRIPT_COUNT_PHP, V_SCRIPT_LOG_PHP
							  FROM OM_CONFIG_MEDIDA_VARIAVEL
							 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
							   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
							   AND IDTPSCRIPT = 'PHP';
						EXCEPTION
							WHEN NO_DATA_FOUND THEN BEGIN
								V_SCRIPT_COUNT_PHP := NULL;
								V_SCRIPT_LOG_PHP   := NULL;
							END;
						END;
						
					END IF;
					
					/*SQL*/
					
					IF (V_SCRIPT_COUNT_SQL IS NULL) THEN
					
						BEGIN	
							SELECT PHP_SCRIPT_COUNT AS SCRIPT_COUNT, PHP_SCRIPT_LOG AS SCRIPT_LOG
							  INTO V_SCRIPT_COUNT_SQL, V_SCRIPT_LOG_SQL
							  FROM OM_CONFIG_MEDIDA_VARIAVEL
							 WHERE NRPRODUTO_ID = SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ))
							   AND CDTPMEDIDASERV = C_MEDICAO.CDTPMEDIDAVARIAVEL
							   AND IDTPSCRIPT = 'SQL';
						EXCEPTION
							WHEN NO_DATA_FOUND THEN BEGIN
								V_SCRIPT_COUNT_SQL := NULL;
								V_SCRIPT_LOG_SQL   := NULL;
							END;
						END;
						
					END IF;
					
					IF ((V_SCRIPT_COUNT_PHP IS NULL) AND (V_SCRIPT_COUNT_SQL IS NULL)) THEN
					
						V_DSOBSCOLETA := V_DSOBSCOLETA||' | Não foi encontrado nenhum script cadastrado para o produto "'||C_MEDICAO.NMELEMENTO||'" com a medida "'||C_MEDICAO.DSTPMEDIDASERV||'"';
					
					END IF;
					
					/* GRAVA DADOS */
		
					/* 1- Dados do Contrato */
					OUT_RECORD.NRSEQCONTRATO       := C_MEDICAO.NRSEQCONTRATO;
					OUT_RECORD.CONTRATO            := C_MEDICAO.NRCONTRATOFCT;
					OUT_RECORD.NRPARCNEGOCIO       := C_MEDICAO.NRPARCNEGOCIO;
					OUT_RECORD.NMPARCEIRO          := C_MEDICAO.NMPRINCIPALPARC||' - ('||C_MEDICAO.NMSECUNDARIPARC||')';
					OUT_RECORD.ORGANIZACAOPARC     := V_ORGANIZACAO; 
					OUT_RECORD.IDTIPOORG           := V_IDTIPOORG;
					OUT_RECORD.DTINICOMPET         := C_MEDICAO.DTINICOMPET;
					OUT_RECORD.DTFINCOMPET         := C_MEDICAO.DTFINCOMPET;
					OUT_RECORD.CDSERVORCA          := C_MEDICAO.CDSERVORCA;
					OUT_RECORD.NMSERVORCA          := C_MEDICAO.NMSERVORCA;
					OUT_RECORD.IDELEMENTORAIZ      := SUBSTR(C_MEDICAO.IDELEMENTORAIZ, 3, LENGTH(C_MEDICAO.IDELEMENTORAIZ)); 
					OUT_RECORD.NMELEMENTO          := C_MEDICAO.NMELEMENTO;
					OUT_RECORD.DSTIPOELEMENTO      := V_DSTIPOELEMENTO; 
					OUT_RECORD.CDTPMEDIDAVARIAVEL  := C_MEDICAO.CDTPMEDIDAVARIAVEL; 
					OUT_RECORD.DSTPMEDIDASERV      := C_MEDICAO.DSTPMEDIDASERV;
					OUT_RECORD.PREPSTATUS          := V_PREPSTATUS;
					OUT_RECORD.NRORGPRINCIPAL      := V_NRORGPRINCIPAL;
					OUT_RECORD.NMORGPRINCIPAL      := V_NMORGPRINCIPAL;
					
					/* 2- Dados de Medição */
					OUT_RECORD.QTCONTRATUAL        := C_MEDICAO.QTCONTRATUAL;
					OUT_RECORD.QTMEDIDA            := C_MEDICAO.QTMEDIDA;
					OUT_RECORD.QTFATURADA          := C_MEDICAO.QTFATURADA;
					OUT_RECORD.DTULTIMACOLETAOM    := C_MEDICAO.DTULTIMACOLETAOM; 
					OUT_RECORD.QTULTIMAMEDIDAOM    := C_MEDICAO.QTULTIMAMEDIDAOM;
					
					/* 3- Dados da Situação */
					OUT_RECORD.IDSTATUS            := V_STATUS;
					
					IF (V_STATUS = 'O') THEN
						OUT_RECORD.IDSEMERRO       :=  'N';
					ELSE
						OUT_RECORD.IDSEMERRO       :=  'S';
					END IF;
					
					OUT_RECORD.DSOBSCOLETA         := V_DSOBSCOLETA;
					
					/* 4- Dados de Parametrização / Servidor */
					OUT_RECORD.IDLOCALCOLETOR      := V_IDLOCALCOLETOR;
					OUT_RECORD.SERVIDOR            := V_SERVIDOR;  
					OUT_RECORD.DSSTRINGCONEXAO     := REPLACE(V_DSSTRINGCONEXAO, '[NRORG]', V_ORGANIZACAO); 
					OUT_RECORD.IDUTWALLET          := V_IDUTWALLET; 
					OUT_RECORD.IDCOLETOR           := V_IDCOLETOR;
					OUT_RECORD.IDTPBANCO           := V_IDTPBANCO;
					OUT_RECORD.IDTPCOLETA          := C_MEDICAO.IDTPCOLETAMEDIDASERV;
					OUT_RECORD.SCRIPT_COUNT_SQL    := V_SCRIPT_COUNT_SQL;
					OUT_RECORD.SCRIPT_LOG_SQL      := V_SCRIPT_LOG_SQL;
					OUT_RECORD.SCRIPT_COUNT_PHP    := V_SCRIPT_COUNT_PHP;
					OUT_RECORD.SCRIPT_LOG_PHP      := V_SCRIPT_LOG_PHP;
					OUT_RECORD.DTINCLUSAOERRO      := C_ERROS2.DTINCLUSAO;
					
					/*5- NRORG E Data de Inclusão*/
					OUT_RECORD.NRORG               := P_NRORG;
					OUT_RECORD.DTINCLUSAO          := SYSDATE;

					PIPE ROW (OUT_RECORD);
					
				END LOOP;
			
			END IF;
			
		END IF;
		
	END LOOP;

	RETURN;

END;

/